summaryrefslogtreecommitdiff
path: root/doc/python3.rst
diff options
context:
space:
mode:
authorAurélien (avd) <avd@odoo.com>2021-03-03 16:43:43 +0000
committerAurélien (avd) <avd@odoo.com>2021-04-16 08:25:41 +0000
commit3e20e68f0790a0b0f3b5c4d43f59f235b7d20fef (patch)
tree030b76926691eceeddfad129a0192fb731ed35e7 /doc/python3.rst
parent02886f65e9026e1f7617c8b23c3d87edd358b168 (diff)
[FIX] calendar: improve calendar recurrency creation performances
Improve calendar recurrency creation performances by moving the call to super().create out of the for loop. For a client database with 120 recurrences creating around 50k calendar events in total, the 5 times averaged execution time went from 1410s to 630s, so a speed up slightly bigger than 2.
Diffstat (limited to 'doc/python3.rst')
0 files changed, 0 insertions, 0 deletions